==> uracoli-0.0.9-src.zip: uracoli-0.0.9/Src/Lib/Ioutil/hif_ft245.c <==
/* Copyright (c) 2007 Axel Wachtler
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   * Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
   * Neither the name of the authors nor the names of its contributors
     may be used to endorse or promote products derived from this software
     without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */

/* $Id: hif_ft245.c,v 1.2 2009/05/05 05:26:16 awachtler Exp $ */

/* === includes ========================================== */
#include <stdio.h>
#include <stdarg.h>
#include <string.h>
#include "board.h"
#include "ioutil.h"
#if HIF_TYPE == HIF_FT245

/* === macros ============================================ */

/* === types ============================================= */

/* === globals =========================================== */
volatile char * pUSB_Fifo;
volatile uint8_t HifError;

/* === prototypes ======================================== */

/* === functions ========================================= */
void hif_init(const uint16_t baudrate)
{
    pUSB_Fifo = (volatile char *)USB_FIFO_AD;
    HIF_IO_ENABLE();
}

void hif_puts_p(const char *progmem_s)
{
    register char c;
    uint8_t cnt;
    while ( (c = pgm_read_byte(progmem_s++)) != 0 )
    {
        *pUSB_Fifo = c;
        for(cnt=0;
            cnt<255;
            cnt++)
        {
            if( FT245_TX_DATA() != TX_IS_BLOCKED )
            {
                break;
            }
            DELAY_US(2);
        }
        if (cnt==255)
        {
            HifError = 1;
            return;
        }
    }
}

void hif_puts(const char *s)
{
    register char c;
    uint8_t cnt;
    while ((c = *s++) != 0)
    {
        *pUSB_Fifo = c;
        for(cnt=0;  cnt<255; cnt++)
        {
           if (FT245_TX_DATA() != TX_IS_BLOCKED)
           {
               break;
           }
           DELAY_US(2);
        }
        if (cnt==255)
        {
            HifError = 1;
            return;
        }
    }
}

uint8_t hif_put_blk(unsigned char *data, uint8_t size)
{
    memcpy((void*)pUSB_Fifo, data, size);
    return size;
}

unsigned int hif_getc()
{
unsigned int ret;
    if(FT245_RX_DATA() == RX_HAS_DATA)
    {
        ret = (unsigned int) *pUSB_Fifo;
    }
    else
    {
        ret = HIF_NO_DATA;
    }
    return ret;
}


uint8_t hif_get_blk(unsigned char *data, uint8_t max_size)
{
    uint8_t cnt = 0;

    while((FT245_RX_DATA() == RX_HAS_DATA) && (cnt < max_size))
    {
        *data++ = (unsigned char) *pUSB_Fifo;
    }

    return cnt;
}

void hif_putc(unsigned char data)
{
    *pUSB_Fifo = data;
}

#endif

==> uracoli-0.0.11-src.zip: uracoli-0.0.11/Src/Lib/Ioutil/hif_ft245.c <==
/* Copyright (c) 2007 Axel Wachtler
   Copyright (c) 2009 Joerg Wunsch
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   * Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
   * Neither the name of the authors nor the names of its contributors
     may be used to endorse or promote products derived from this software
     without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */

/* $Id: hif_ft245.c,v 1.4 2009/08/20 05:18:21 awachtler Exp $ */

/* === includes ========================================== */
#include <stdio.h>
#include <stdarg.h>
#include <string.h>
#include "board.h"
#include "ioutil.h"
#if HIF_TYPE == HIF_FT245

/* === macros ============================================ */

/* === types ============================================= */

/* === globals =========================================== */
static volatile char * pUSB_Fifo;
static uint8_t HifError;        /** @todo there is no way the user can access this */

/* === prototypes ======================================== */

/* === functions ========================================= */
void hif_init(const uint16_t baudrate)
{
    pUSB_Fifo = (volatile char *)USB_FIFO_AD;
    HifError = 0;
    HIF_IO_ENABLE();
}

void hif_puts_p(const char *progmem_s)
{
    register char c;
    uint8_t cnt;

    if (HifError)
        // Caller did not clear the last error, bail out.
        return;

    while ( (c = pgm_read_byte(progmem_s++)) != 0 )
    {
        *pUSB_Fifo = c;
        for(cnt=0;
            cnt<255;
            cnt++)
        {
            if( FT245_TX_DATA() != TX_IS_BLOCKED )
            {
                break;
            }
            DELAY_US(20);
        }
        if (cnt==255)
        {
            HifError = 1;
            return;
        }
    }
}

void hif_puts(const char *s)
{
    register char c;
    uint8_t cnt;

    if (HifError)
        // Caller did not clear the last error, bail out.
        return;

    while ((c = *s++) != 0)
    {
        *pUSB_Fifo = c;
        for(cnt=0;  cnt<255; cnt++)
        {
           if (FT245_TX_DATA() != TX_IS_BLOCKED)
           {
               break;
           }
           DELAY_US(20);
        }
        if (cnt==255)
        {
            HifError = 1;
            return;
        }
    }
}

uint8_t hif_put_blk(unsigned char *data, uint8_t size)
{
    uint8_t cnt;
    uint8_t xfered;

    if (HifError)
        // Caller did not clear the last error, bail out.
        return 0;

    for (xfered = 0; size != 0; xfered++, size--)
    {
        *pUSB_Fifo = *data++;
        for(cnt=0;  cnt<255; cnt++)
        {
           if (FT245_TX_DATA() != TX_IS_BLOCKED)
           {
               break;
           }
           DELAY_US(20);
        }
        if (cnt==255)
        {
            HifError = 1;
            return xfered;
        }
    }
    return xfered;
}

unsigned int hif_getc()
{
unsigned int ret;
    if(FT245_RX_DATA() == RX_HAS_DATA)
    {
        ret = (unsigned int) *pUSB_Fifo;
    }
    else
    {
        ret = HIF_NO_DATA;
    }
    return ret;
}


uint8_t hif_get_blk(unsigned char *data, uint8_t max_size)
{
    uint8_t cnt = 0;

    while((FT245_RX_DATA() == RX_HAS_DATA) && (cnt < max_size))
    {
        *data++ = (unsigned char) *pUSB_Fifo;
        cnt++;
    }

    return cnt;
}

void hif_putc(unsigned char data)
{
    uint8_t cnt;

    if (HifError)
        // Caller did not clear the last error, bail out.
        return;

    *pUSB_Fifo = data;

    for(cnt=0;  cnt<255; cnt++)
    {
        if (FT245_TX_DATA() != TX_IS_BLOCKED)
        {
            break;
        }
        DELAY_US(20);
    }
    if (cnt==255)
    {
        HifError = 1;
    }
}

#endif
